@@ -24,7 +24,7 @@ TEMP_FOLDER = None
 
 
 def setup_module():
-    setup_autokill(__name__, timeout=30)
+    setup_autokill(__name__, timeout=300)
 
 
 def teardown_module():
@@ -347,6 +347,12 @@ def test_memmaping_pool_for_large_arrays():
         dumped_filenames = os.listdir(p._temp_folder)
         assert_equal(len(dumped_filenames), 2)
 
+        # Check that memmory mapping is not triggered for arrays with
+        # dtype='object'
+        objects = np.array(['abc'] * 100, dtype='object')
+        results = p.map(has_shareable_memory, [objects])
+        assert_false(results[0])
+
     finally:
         # check FS garbage upon pool termination
         p.terminate()
@@ -384,7 +390,7 @@ def test_memmaping_pool_for_large_arrays_disabled():
 @with_multiprocessing
 @with_dev_shm
 def test_memmaping_on_dev_shm():
-    """Check that large arrays memmaping can be disabled"""
+    """Check that MemmapingPool uses /dev/shm when possible"""
     p = MemmapingPool(3, max_nbytes=10)
     try:
         # Check that the pool has correctly detected the presence of the
